InverseHarmonicMeanRank
=======================

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: InverseHarmonicMeanRank
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~InverseHarmonicMeanRank.increasing
      ~InverseHarmonicMeanRank.name
      ~InverseHarmonicMeanRank.synonyms
      ~InverseHarmonicMeanRank.value_range

   .. rubric:: Methods Summary

   .. autosummary::

      ~InverseHarmonicMeanRank.__call__
      ~InverseHarmonicMeanRank.expected_value
      ~InverseHarmonicMeanRank.variance

   .. rubric:: Attributes Documentation

   .. autoattribute:: increasing
   .. autoattribute:: name
   .. autoattribute:: synonyms
   .. autoattribute:: value_range

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: expected_value
   .. automethod:: variance
